xquery version "3.1";
(:~
 : This module serves for displaying the information about the BdN project that
 : is stored in its specific XML-file.
 :
 : The German version can be found at /db/apps/sade/textgrid/data/@@@.
 : The English version can be found at /db/apps/sade/textgrid/data/@@@.
 :
 : @author Michelle Weidling
 : @version 1.0
:)
module namespace bdn-project="https://bdn-edition.de/ns/project";

declare namespace bdn="http://www.bdn-edition.de/ns/1.0";
declare namespace svg="http://www.w3.org/2000/svg";
declare namespace tei="http://www.tei-c.org/ns/1.0";
declare namespace templates="http://exist-db.org/xquery/templates";
declare namespace tgmd="http://textgrid.info/namespaces/metadata/core/2010";
declare namespace xhtml="http://www.w3.org/1999/xhtml";
declare namespace xlink="http://www.w3.org/1999/xlink";

import module namespace config="https://sade.textgrid.de/ns/config" at "../config.xqm";

declare variable $bdn-project:img-path := "templates/img/";

declare function bdn-project:main($node as node(), $model as map(*))
{
  let $lang := request:get-parameter("lang", "de")
  let $file := doc($config:sade-data || "project-" || $lang || ".xml") (: @@ TODO: insert right file :)
  let $root := $file/*
  let $html := local:render($root)
  return $html
};

declare function local:render($nodes as node()*) as item()*
{
  for $node in $nodes
  return
    typeswitch ($node)
    case text() return
      $node

    case element(root) return
      local:render($node/node())

    case element(head) return
      if ($node[@type = "main"]) then
        <div class="block-header">
          <h2>
            <span class="title">{local:render($node/node())}</span>
            <span class="decoration" />
            <span class="decoration" />
            <span class="decoration" />
          </h2>
        </div>
      else
        <div class="block-sub-header">
          <h3>
            <span class="title-text">{local:render($node/node())}</span>
            <span class="decoration" />
            <span class="decoration" />
            <span class="decoration" />
          </h3>
        </div>

    case element(p) return
      <p>{local:render($node/node())}</p>

    case element(hi) return
      <em>{local:render($node/node())}</em>

    case element(table) return
      element xhtml:table
      {
        if ($node[@class]) then
          attribute class {$node/@class}
        else
          (),
        local:render($node/node())
      }

    case element(row) return
      <tr>{local:render($node/node())}</tr>

    case element(cell) return
      element xhtml:td
      {
        if ($node[@role]) then
          attribute class {$node/@role}
        else
          (),
        local:render($node/node())
      }

    case element(list) return
      if ($node[@type]) then
        <ul>{local:render($node/node())}</ul>
      else
        <ol style="list-style-type: upper-roman;">{local:render($node/node())}</ol>

    case element(item) return
      <li>{local:render($node/node())}</li>

    case element(sup) return
      <sup>{local:render($node/node())}</sup>

    default return
      ()
};
